re: [linux-usb-devel] problem with Ego technology music disk MD100USB storage device (add PowerColor MUSICDISK too)

2003-04-01 Thread Alan Stern
(Unfortunately the sourceforge mail archive doesn't include complete 
sender addresses, so I can't copy this message to Peter De Schrijver.)

On 31 Mar 2003, Chris Worley wrote:

 [I didn't see this in the archives from Sunday; I apologize if this is a
 repost; if there is a more appropriate place to post, please tell me]
 
 On 2003-02-05 21:23:43 Peter 'p2' De Schrijver wrote:
  Hi,
  
  I'm trying to get the Ego Technology MD100 to work under linux. It's
  small MP3 player gadget which has 128MB of flash and a USB interface.
 It
  identifies itself as a USB storage device. When I try to read from it
  under linux, the process doing the read just hangs. The device works
  under windows 2000 with the default windows USB storage driver. 
  I'm running the stock 2.4.20 linux kernel. 
  
  attached is the dmesg output, the output of /proc/bus/usb/devices and
  .config of the kernel.
  ...snip a few thousand lines...
 
 Peter,
 
 Did you ever get an answer?  Were you able to get this working?
 
 I have the same device, although it's marketed differently (claiming
 Linux 2.4.x compatibility!) as a PowerColor MD100 128MB Portable
 Storage/Music DISK USB MP3 Player:
 
 http://www.ateck.com/viewItem.asp?idProduct=453055232
 
 From the vendor power-color.com:
 
 http://www.power-color.com/html/md100.html
 
 But, it has the same USB device/product ID's as yours (0x8341/0x2000).
 
 Furthermore, I have the exact same problem.  I've tried it on 5
 different Linux Boxes, ranging from SuSE 7.3 to 8.1 and RedHat 7.2 to
 7.3.  The kernels range from 2.4.9 to 2.4.20; all have USB properly
 installed and working for other devices, including other pen drives.
 
 The SuSE based machines hang tight (need to power cycle) about a minute
 after installation of the device.  On the RedHat machines, they see the
 device, but any attempt to read the device (i.e. fdisk -l, dd
 if=/dev/sda of=/dev/null, mount /dev/sda ...) locks up the process
 and either the usb-storage or the sd_mod driver (I don't know which).
 
 Peter's information, at:
 
  http://sourceforge.net/mailarchive/message.php?msg_id=3737890
 
 ...was much more in-depth, but I'll add:
 

Judging from the information in Peter's message, it looks like the problem 
stems from the use of a START-STOP command.  The patch below removes that 
command; it's a backport from 2.5.  It applies to 2.4.21-pre6.  Try it and 
let me know if it helps.

Alan Stern


--- linux-2.4.21/drivers/scsi/sd.c.orig Mon Mar 31 16:27:31 2003
+++ linux-2.4.21/drivers/scsi/sd.c  Mon Mar 31 16:56:20 2003
@@ -731,15 +731,17 @@
 * check_disk_change */
}
 
    /* Using Start/Stop enables differentiation between drive with
 * no cartridge loaded - NOT READY, drive with changed cartridge -
 * UNIT ATTENTION, or with same cartridge - GOOD STATUS.
-* This also handles drives that auto spin down. eg iomega jaz 1GB
-* as this will spin up the drive.
+*
+* Drives that auto spin down. eg iomega jaz 1G, will be started
+* by sd_init_onedisk(), whenever revalidate_scsidisk() is called.
 */
retval = -ENODEV;
if (scsi_block_when_processing_errors(SDev))
-   retval = scsi_ioctl(SDev, SCSI_IOCTL_START_UNIT, NULL);
+   retval = scsi_ioctl(SDev, SCSI_IOCTL_TEST_UNIT_READY, NULL);
 
if (retval) {   /* Unable to test, unit probably not ready.
 * This usually means there is no disc in the



---
This SF.net email is sponsored by: ValueWeb: 
Dedicated Hosting for just $79/mo with 500 GB of bandwidth! 
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
___
[EMAIL PROTECTED]
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel


re: [linux-usb-devel] problem with Ego technology music disk MD100USB storage device (add PowerColor MUSICDISK too)

2003-04-01 Thread Chris Worley
Bingo.

This worked great.  There was a little tweak on the sd.c patch for the
2.4.19 kernel, but it was apparent.

Thanks!

Chris

On Tue, 2003-04-01 at 07:59, Alan Stern wrote:
 (Unfortunately the sourceforge mail archive doesn't include complete 
 sender addresses, so I can't copy this message to Peter De Schrijver.)
 
 On 31 Mar 2003, Chris Worley wrote:
 
  [I didn't see this in the archives from Sunday; I apologize if this is a
  repost; if there is a more appropriate place to post, please tell me]
  
  On 2003-02-05 21:23:43 Peter 'p2' De Schrijver wrote:
   Hi,
   
   I'm trying to get the Ego Technology MD100 to work under linux. It's
   small MP3 player gadget which has 128MB of flash and a USB interface.
  It
   identifies itself as a USB storage device. When I try to read from it
   under linux, the process doing the read just hangs. The device works
   under windows 2000 with the default windows USB storage driver. 
   I'm running the stock 2.4.20 linux kernel. 
   
   attached is the dmesg output, the output of /proc/bus/usb/devices and
   .config of the kernel.
   ...snip a few thousand lines...
  
  Peter,
  
  Did you ever get an answer?  Were you able to get this working?
  
  I have the same device, although it's marketed differently (claiming
  Linux 2.4.x compatibility!) as a PowerColor MD100 128MB Portable
  Storage/Music DISK USB MP3 Player:
  
  http://www.ateck.com/viewItem.asp?idProduct=453055232
  
  From the vendor power-color.com:
  
  http://www.power-color.com/html/md100.html
  
  But, it has the same USB device/product ID's as yours (0x8341/0x2000).
  
  Furthermore, I have the exact same problem.  I've tried it on 5
  different Linux Boxes, ranging from SuSE 7.3 to 8.1 and RedHat 7.2 to
  7.3.  The kernels range from 2.4.9 to 2.4.20; all have USB properly
  installed and working for other devices, including other pen drives.
  
  The SuSE based machines hang tight (need to power cycle) about a minute
  after installation of the device.  On the RedHat machines, they see the
  device, but any attempt to read the device (i.e. fdisk -l, dd
  if=/dev/sda of=/dev/null, mount /dev/sda ...) locks up the process
  and either the usb-storage or the sd_mod driver (I don't know which).
  
  Peter's information, at:
  
   http://sourceforge.net/mailarchive/message.php?msg_id=3737890
  
  ...was much more in-depth, but I'll add:
  
 
 Judging from the information in Peter's message, it looks like the problem 
 stems from the use of a START-STOP command.  The patch below removes that 
 command; it's a backport from 2.5.  It applies to 2.4.21-pre6.  Try it and 
 let me know if it helps.
 
 Alan Stern
 
 
 --- linux-2.4.21/drivers/scsi/sd.c.orig   Mon Mar 31 16:27:31 2003
 +++ linux-2.4.21/drivers/scsi/sd.cMon Mar 31 16:56:20 2003
 @@ -731,15 +731,17 @@
* check_disk_change */
   }
  
 - /* Using Start/Stop enables differentiation between drive with
 + /*
 +  * Using TEST_UNIT_READY enables differentiation between drive with
* no cartridge loaded - NOT READY, drive with changed cartridge -
* UNIT ATTENTION, or with same cartridge - GOOD STATUS.
 -  * This also handles drives that auto spin down. eg iomega jaz 1GB
 -  * as this will spin up the drive.
 +  *
 +  * Drives that auto spin down. eg iomega jaz 1G, will be started
 +  * by sd_init_onedisk(), whenever revalidate_scsidisk() is called.
*/
   retval = -ENODEV;
   if (scsi_block_when_processing_errors(SDev))
 - retval = scsi_ioctl(SDev, SCSI_IOCTL_START_UNIT, NULL);
 + retval = scsi_ioctl(SDev, SCSI_IOCTL_TEST_UNIT_READY, NULL);
  
   if (retval) {   /* Unable to test, unit probably not ready.
* This usually means there is no disc in the
 
 
 
 ---
 This SF.net email is sponsored by: ValueWeb: 
 Dedicated Hosting for just $79/mo with 500 GB of bandwidth! 
 No other company gives more support or power for your dedicated server
 http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
 ___
 [EMAIL PROTECTED]
 To unsubscribe, use the last form field at:
 https://lists.sourceforge.net/lists/listinfo/linux-usb-devel




---
This SF.net email is sponsored by: ValueWeb: 
Dedicated Hosting for just $79/mo with 500 GB of bandwidth! 
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
___
[EMAIL PROTECTED]
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel


re: [linux-usb-devel] problem with Ego technology music disk MD100USB storage device (add PowerColor MUSICDISK too)

2003-03-31 Thread Chris Worley
[I didn't see this in the archives from Sunday; I apologize if this is a
repost; if there is a more appropriate place to post, please tell me]

On 2003-02-05 21:23:43 Peter 'p2' De Schrijver wrote:
 Hi,
 
 I'm trying to get the Ego Technology MD100 to work under linux. It's
 small MP3 player gadget which has 128MB of flash and a USB interface.
It
 identifies itself as a USB storage device. When I try to read from it
 under linux, the process doing the read just hangs. The device works
 under windows 2000 with the default windows USB storage driver. 
 I'm running the stock 2.4.20 linux kernel. 
 
 attached is the dmesg output, the output of /proc/bus/usb/devices and
 .config of the kernel.
 ...snip a few thousand lines...

Peter,

Did you ever get an answer?  Were you able to get this working?

I have the same device, although it's marketed differently (claiming
Linux 2.4.x compatibility!) as a PowerColor MD100 128MB Portable
Storage/Music DISK USB MP3 Player:

http://www.ateck.com/viewItem.asp?idProduct=453055232

From the vendor power-color.com:

http://www.power-color.com/html/md100.html

But, it has the same USB device/product ID's as yours (0x8341/0x2000).

Furthermore, I have the exact same problem.  I've tried it on 5
different Linux Boxes, ranging from SuSE 7.3 to 8.1 and RedHat 7.2 to
7.3.  The kernels range from 2.4.9 to 2.4.20; all have USB properly
installed and working for other devices, including other pen drives.

The SuSE based machines hang tight (need to power cycle) about a minute
after installation of the device.  On the RedHat machines, they see the
device, but any attempt to read the device (i.e. fdisk -l, dd
if=/dev/sda of=/dev/null, mount /dev/sda ...) locks up the process
and either the usb-storage or the sd_mod driver (I don't know which).

Peter's information, at:

 http://sourceforge.net/mailarchive/message.php?msg_id=3737890

...was much more in-depth, but I'll add:

/var/log/messages output:

Mar 29 11:13:03 localhost kernel: hub.c: USB new device connect on bus1/2, 
assigned device number 5
Mar 29 11:13:03 localhost kernel: usb.c: USB device 5 (vend/prod 0x8341/0x2000) is 
not claimed by any active driver.
Mar 29 11:13:03 localhost kernel: Initializing USB Mass Storage driver...
Mar 29 11:13:03 localhost kernel: usb.c: registered new driver usb-storage
Mar 29 11:13:03 localhost kernel: scsi1 : SCSI emulation for USB Mass Storage 
devices
Mar 29 11:13:03 localhost kernel:   Vendor: MUSIC Model: DISK  
Rev: 1.00
Mar 29 11:13:03 localhost kernel:   Type:   Direct-Access  
ANSI SCSI revision: 02
Mar 29 11:13:03 localhost kernel: USB Mass Storage support registered.

/proc/bus/usb/devices output:

T:  Bus=01 Lev=00 Prnt=00 Port=00 Cnt=00 Dev#=  1 Spd=12  MxCh= 2
B:  Alloc=  0/900 us ( 0%), #Int=  0, #Iso=  0
D:  Ver= 1.10 Cls=09(hub  ) Sub=00 Prot=00 MxPS= 8 #Cfgs=  1
P:  Vendor= ProdID= Rev= 0.00
S:  Product=USB OHCI Root Hub
S:  SerialNumber=e086f000
C:* #Ifs= 1 Cfg#= 1 Atr=40 MxPwr=  0mA
I:  If#= 0 Alt= 0 #EPs= 1 Cls=09(hub  ) Sub=00 Prot=00 Driver=hub
E:  Ad=81(I) Atr=03(Int.) MxPS=   2 Ivl=255ms
T:  Bus=01 Lev=01 Prnt=01 Port=01 Cnt=01 Dev#=  5 Spd=12  MxCh= 0
D:  Ver= 1.10 Cls=00(ifc ) Sub=00 Prot=00 MxPS= 8 #Cfgs=  1
P:  Vendor=8341 ProdID=2000 Rev= 1.00
C:* #Ifs= 1 Cfg#= 1 Atr=80 MxPwr=100mA
I:  If#= 0 Alt= 0 #EPs= 2 Cls=08(stor.) Sub=06 Prot=50 Driver=usb-storage
E:  Ad=81(I) Atr=02(Bulk) MxPS=  64 Ivl=  0ms
E:  Ad=02(O) Atr=02(Bulk) MxPS=  64 Ivl=  0ms

/proc/scsi/scsi output:

Attached devices:
Host: scsi0 Channel: 00 Id: 00 Lun: 00
  Vendor: TOSHIBA  Model: DVD-ROM SD-C2502 Rev: 1313
  Type:   CD-ROM   ANSI SCSI revision: 02
Host: scsi1 Channel: 00 Id: 00 Lun: 00
  Vendor: MUSICModel: DISK Rev: 1.00
  Type:   Direct-AccessANSI SCSI revision: 02

/proc/partitions output (only /dev/sda* matter):

major minor  #blocks  name rio rmerge rsect ruse wio wmerge wsect wuse running 
use aveq

   8 0 128000 sda 0 0 0 0 0 0 0 0 0 0 0
   8 1 127728 sda1 0 0 0 0 0 0 0 0 0 0 0
   3 0   19535040 hda 5670 13237 148564 114750 2936 6672 76910 55650 0 72890 
170400
   3 1  48163 hda1 28 421 898 580 11 4 30 30 0 480 610
   3 2   18996862 hda2 5640 12816 147650 114100 2925 6668 76880 55620 0 72590 
169720
   3 3 489982 hda3 2 0 16 70 0 0 0 0 0 70 70

Any help would be appreciated!

Thanks,

Chris




---
This SF.net email is sponsored by: ValueWeb: 
Dedicated Hosting for just $79/mo with 500 GB of bandwidth! 
No other company gives more support or power for your dedicated server
http://click.atdmt.com/AFF/go/sdnxxaff00300020aff/direct/01/
___
[EMAIL PROTECTED]
To unsubscribe, use the last form 

re: [linux-usb-devel] problem with Ego technology music disk MD100USB storage device (add PowerColor MUSICDISK too)

2003-03-30 Thread Chris Worley
On 2003-02-05 21:23:43 Peter 'p2' De Schrijver wrote:
 Hi,
 
 I'm trying to get the Ego Technology MD100 to work under linux. It's
 small MP3 player gadget which has 128MB of flash and a USB interface. It
 identifies itself as a USB storage device. When I try to read from it
 under linux, the process doing the read just hangs. The device works
 under windows 2000 with the default windows USB storage driver. 
 I'm running the stock 2.4.20 linux kernel. 
 
 attached is the dmesg output, the output of /proc/bus/usb/devices and
 .config of the kernel.
 ...snip a few thousand lines...

Peter,

Did you ever get an answer?  Were you able to get this working?

I have the same device, although it's marketed differently (claiming
Linux 2.4.x compatibility!) as a PowerColor MD100 128MB Portable
Storage/Music DISK USB MP3 Player:

http://www.ateck.com/viewItem.asp?idProduct=453055232

From the vendor power-color.com:

http://www.power-color.com/html/md100.html

But, it has the same USB device/product ID's as yours (0x8341/0x2000).

Furthermore, I have the exact same problem.  I've tried it on 5
different Linux Boxes, ranging from SuSE 7.3 to 8.1 and RedHat 7.2 to
7.3.  The kernels range from 2.4.9 to 2.4.20; all have USB properly
installed and working for other devices, including other pen drives.

The SuSE based machines hang tight (need to power cycle) about a minute
after installation of the device.  On the RedHat machines, they see the
device, but any attempt to read the device (i.e. fdisk -l, dd
if=/dev/sda of=/dev/null, mount /dev/sda ...) locks up the process
and either the usb-storage or the sd_mod driver (I don't know which).

Peter's information, at:

 http://sourceforge.net/mailarchive/message.php?msg_id=3737890

...was much more in-depth, but I'll add:

/var/log/messages output:

Mar 29 11:13:03 localhost kernel: hub.c: USB new device connect on bus1/2, 
assigned device number 5
Mar 29 11:13:03 localhost kernel: usb.c: USB device 5 (vend/prod 0x8341/0x2000) is 
not claimed by any active driver.
Mar 29 11:13:03 localhost kernel: Initializing USB Mass Storage driver...
Mar 29 11:13:03 localhost kernel: usb.c: registered new driver usb-storage
Mar 29 11:13:03 localhost kernel: scsi1 : SCSI emulation for USB Mass Storage 
devices
Mar 29 11:13:03 localhost kernel:   Vendor: MUSIC Model: DISK  
Rev: 1.00
Mar 29 11:13:03 localhost kernel:   Type:   Direct-Access  
ANSI SCSI revision: 02
Mar 29 11:13:03 localhost kernel: USB Mass Storage support registered.

/proc/bus/usb/devices output:

T:  Bus=01 Lev=00 Prnt=00 Port=00 Cnt=00 Dev#=  1 Spd=12  MxCh= 2
B:  Alloc=  0/900 us ( 0%), #Int=  0, #Iso=  0
D:  Ver= 1.10 Cls=09(hub  ) Sub=00 Prot=00 MxPS= 8 #Cfgs=  1
P:  Vendor= ProdID= Rev= 0.00
S:  Product=USB OHCI Root Hub
S:  SerialNumber=e086f000
C:* #Ifs= 1 Cfg#= 1 Atr=40 MxPwr=  0mA
I:  If#= 0 Alt= 0 #EPs= 1 Cls=09(hub  ) Sub=00 Prot=00 Driver=hub
E:  Ad=81(I) Atr=03(Int.) MxPS=   2 Ivl=255ms
T:  Bus=01 Lev=01 Prnt=01 Port=01 Cnt=01 Dev#=  5 Spd=12  MxCh= 0
D:  Ver= 1.10 Cls=00(ifc ) Sub=00 Prot=00 MxPS= 8 #Cfgs=  1
P:  Vendor=8341 ProdID=2000 Rev= 1.00
C:* #Ifs= 1 Cfg#= 1 Atr=80 MxPwr=100mA
I:  If#= 0 Alt= 0 #EPs= 2 Cls=08(stor.) Sub=06 Prot=50 Driver=usb-storage
E:  Ad=81(I) Atr=02(Bulk) MxPS=  64 Ivl=  0ms
E:  Ad=02(O) Atr=02(Bulk) MxPS=  64 Ivl=  0ms

/proc/scsi/scsi output:

Attached devices:
Host: scsi0 Channel: 00 Id: 00 Lun: 00
  Vendor: TOSHIBA  Model: DVD-ROM SD-C2502 Rev: 1313
  Type:   CD-ROM   ANSI SCSI revision: 02
Host: scsi1 Channel: 00 Id: 00 Lun: 00
  Vendor: MUSICModel: DISK Rev: 1.00
  Type:   Direct-AccessANSI SCSI revision: 02

/proc/partitions output (only /dev/sda* matter):

major minor  #blocks  name rio rmerge rsect ruse wio wmerge wsect wuse running 
use aveq

   8 0 128000 sda 0 0 0 0 0 0 0 0 0 0 0
   8 1 127728 sda1 0 0 0 0 0 0 0 0 0 0 0
   3 0   19535040 hda 5670 13237 148564 114750 2936 6672 76910 55650 0 72890 
170400
   3 1  48163 hda1 28 421 898 580 11 4 30 30 0 480 610
   3 2   18996862 hda2 5640 12816 147650 114100 2925 6668 76880 55620 0 72590 
169720
   3 3 489982 hda3 2 0 16 70 0 0 0 0 0 70 70

Any help would be appreciated!

Thanks,

Chris








---
@@ -731,15 +731,17 @@
}
 
-   /* Using Start/Stop enables differentiation between drive with
+   /*
+* Using TEST_UNIT_READY enables differentiation between drive with
 * no cartridge loaded - NOT READY, drive with changed cartridge -
 * UNIT ATTENTION, or with same cartridge - GOOD STATUS.
This SF.net email is sponsored by:
The Definitive IT and Networking Event. Be There!
NetWorld+Interop Las Vegas 2003 -- Register today!
http://ads.sourceforge.net/cgi-bin/redirect.pl?keyn0001en
___
[EMAIL PROTECTED]
To unsubscribe, use the last form field at:
https://lists.sourceforge.net/lists/listinfo/linux-usb-devel